==> vtk-7.1.1-4-armv7h.pkg.tar.xz: vtk/vtkImageToImageStencil.java <==
// java wrapper for vtkImageToImageStencil object
//

package vtk;
import vtk.*;

public class vtkImageToImageStencil extends vtkImageStencilAlgorithm
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetInputData_2(vtkImageData id0);
  public void SetInputData(vtkImageData id0)
    { SetInputData_2(id0); }

  private native long GetInput_3();
  public vtkImageData GetInput() {
    long temp = GetInput_3();

    if (temp == 0) return null;
    return (vtkImageData)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void ThresholdByUpper_4(double id0);
  public void ThresholdByUpper(double id0)
    { ThresholdByUpper_4(id0); }

  private native void ThresholdByLower_5(double id0);
  public void ThresholdByLower(double id0)
    { ThresholdByLower_5(id0); }

  private native void ThresholdBetween_6(double id0,double id1);
  public void ThresholdBetween(double id0,double id1)
    { ThresholdBetween_6(id0,id1); }

  private native void SetUpperThreshold_7(double id0);
  public void SetUpperThreshold(double id0)
    { SetUpperThreshold_7(id0); }

  private native double GetUpperThreshold_8();
  public double GetUpperThreshold()
    { return GetUpperThreshold_8(); }

  private native void SetLowerThreshold_9(double id0);
  public void SetLowerThreshold(double id0)
    { SetLowerThreshold_9(id0); }

  private native double GetLowerThreshold_10();
  public double GetLowerThreshold()
    { return GetLowerThreshold_10(); }

  public vtkImageToImageStencil() { super(); }

  public vtkImageToImageStencil(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.1.0-6-armv7h.pkg.tar.xz: vtk/vtkImageToImageStencil.java <==
// java wrapper for vtkImageToImageStencil object
//

package vtk;
import vtk.*;

public class vtkImageToImageStencil extends vtkImageStencilAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetInputData_2(vtkImageData id0);
  public void SetInputData(vtkImageData id0)
    { SetInputData_2(id0); }

  private native long GetInput_3();
  public vtkImageData GetInput() {
    long temp = GetInput_3();

    if (temp == 0) return null;
    return (vtkImageData)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void ThresholdByUpper_4(double id0);
  public void ThresholdByUpper(double id0)
    { ThresholdByUpper_4(id0); }

  private native void ThresholdByLower_5(double id0);
  public void ThresholdByLower(double id0)
    { ThresholdByLower_5(id0); }

  private native void ThresholdBetween_6(double id0,double id1);
  public void ThresholdBetween(double id0,double id1)
    { ThresholdBetween_6(id0,id1); }

  private native void SetUpperThreshold_7(double id0);
  public void SetUpperThreshold(double id0)
    { SetUpperThreshold_7(id0); }

  private native double GetUpperThreshold_8();
  public double GetUpperThreshold()
    { return GetUpperThreshold_8(); }

  private native void SetLowerThreshold_9(double id0);
  public void SetLowerThreshold(double id0)
    { SetLowerThreshold_9(id0); }

  private native double GetLowerThreshold_10();
  public double GetLowerThreshold()
    { return GetLowerThreshold_10(); }

  public vtkImageToImageStencil() { super(); }

  public vtkImageToImageStencil(long id) { super(id); }
  public native long   VTKInit();

}
